<div align="center">
	<h1 align="center">
		<img src="https://github.com/AbsoluteWinter/AbsoluteWinter.github.io/blob/main/absfuyu/images/repository-image-crop.png?raw=true" alt="absfuyu"/>
	</h1>
	<p align="center">
		<a href="https://pypi.org/project/absfuyu/"><img src="https://img.shields.io/pypi/pyversions/absfuyu?style=flat-square&logo=python" alt="PyPI Supported Versions"/></a>
		<a href="https://pypi.org/project/absfuyu/"><img src="https://img.shields.io/pypi/dm/absfuyu?style=flat-square&color=blue" alt="PyPI Downloads"/></a>
		<a href="https://pypi.org/project/absfuyu/"><img src="https://img.shields.io/pypi/v/absfuyu?style=flat-square&logo=pypi" /></a>
		<a><img src="https://img.shields.io/pypi/l/absfuyu?style=flat-square&logo=github&color=blue"/></a>
		<a><img src="https://img.shields.io/badge/code%20style-black-black?style=flat-square"/></a>
		<a href="https://github.com/astral-sh/ruff"><img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json&style=flat-square" alt="Ruff" style="max-width:100%;"></a>
	</p>
</div>


---

## **SUMMARY:**

*TL;DR: A collection of code*

## **INSTALLATION:**

```bash
$ pip install -U absfuyu
```

## **USAGE:**

```python
import absfuyu
help(absfuyu)
```

## **DOCUMENTATION:**

> [here](https://absolutewinter.github.io/absfuyu/)

## **DEV SETUP**

1. Create virtual environment

```bash
python -m venv env
```

Note: Might need to run this in powershell (windows)

```powershell
Set-ExecutionPolicy -ExecutionPolicy Unrestricted -Scope CurrentUser
```

2. Install required packages

```bash
python -m pip install -e .[full,dev]
```

3. Getting info of dev environment

```bash
hatch env show
```


## **LICENSE:**

MIT License
